==> struts2-core-2.5.6-20161128.161756-23-sources.jar: com/opensymphony/xwork2/config/providers/EnvsValueSubstitutor.java <==
/*
 * Copyright 2002-2006,2009 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.opensymphony.xwork2.config.providers;

import org.apache.commons.lang3.text.StrSubstitutor;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class EnvsValueSubstitutor implements ValueSubstitutor {

    private static final Logger LOG = LogManager.getLogger(EnvsValueSubstitutor.class);

    protected StrSubstitutor strSubstitutor;

    public EnvsValueSubstitutor() {
        strSubstitutor = new StrSubstitutor(System.getenv());
        strSubstitutor.setVariablePrefix("${ENV.");
        strSubstitutor.setVariableSuffix('}');
        strSubstitutor.setValueDelimiter(":");
    }

    @Override
    public String substitute(String value) {
        LOG.debug("Substituting value {} with proper ENV value", value);

        String substituted = StrSubstitutor.replaceSystemProperties(value);
        return strSubstitutor.replace(substituted);
    }
}

==> struts2-core-2.5.7-20161202.072038-5-sources.jar: com/opensymphony/xwork2/config/providers/EnvsValueSubstitutor.java <==
/*
 * Copyright 2002-2006,2009 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.opensymphony.xwork2.config.providers;

import org.apache.commons.lang3.text.StrSubstitutor;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class EnvsValueSubstitutor implements ValueSubstitutor {

    private static final Logger LOG = LogManager.getLogger(EnvsValueSubstitutor.class);

    protected StrSubstitutor strSubstitutor;

    public EnvsValueSubstitutor() {
        strSubstitutor = new StrSubstitutor(System.getenv());
        strSubstitutor.setVariablePrefix("${env.");
        strSubstitutor.setVariableSuffix('}');
        strSubstitutor.setValueDelimiter(":");
    }

    @Override
    public String substitute(String value) {
        LOG.debug("Substituting value {} with proper System variable or environment variable", value);

        String substituted = StrSubstitutor.replaceSystemProperties(value);
        return strSubstitutor.replace(substituted);
    }
}
